# -*- coding: utf-8 -*-
"""
Created on Tue Oct 11 17:29:25 2022

@author: cukelarter

Script for initiating multistep run on multichannel Chemyx Syringe Pump. Tested on Chemyx 4000-X.

After importing serial connection driver we connect to the pump. Connection will remain open
until user calls "conn.closeConnection()". If user does not call this before exiting
the connection will remain locked open until the connection is physically broken (unplugged).
The run will continue to completion after connection is closed.

"""

#%% Import CHEMYX serial connection module/driver
from core import connect

# get open port info
portinfo = connect.getOpenPorts() 

# MUST set baudrate in pump "System Settings", and MUST match this rate:
baudrate=9600
# initiate Connection object with first open port
conn = connect.Connection(port=str(portinfo[0]),baudrate=baudrate, multipump=True)

#%% Connect and Run Pump - Basic Setup
if __name__=='__main__':
    
    # Open Connection to pump
    conn.openConnection()
    
    # Specify which pump is having its parameters modified
    conn.changePump(1)
    
    # Setup parameters for pump 1
    units='mL/min' 			# OPTIONS: 'mL/min','mL/hr','μL/min','μL/hr'
    diameter=28.6           # 28.6mm diameter
    volume=[0.25,5,2]       # Volume = [Step1: 0.25mL, Step2: 5mL, Step3: 2mL]
    delay=[6,12,18]         # Delay  = [Step1: 6s,     Step2: 12s, Step3: 18s]
    
    # Variable flow rates in each step, linear ramping generated by pump
    rate1=[20,5,40]         # between rate1 and rate2 for each step
    rate2=[21,6,41]         # use one rate list for linear flow per step
    varrates=[f'{rate1[ii]}/{rate2[ii]}' for ii in range(len(rate1))]
    # Rate = [Step1: 20mL/min->21mL/min, Step2: 5mL/min->6mL/min, Step3: 40mL/min->41mL/min]
          
    
    # Communicate parameters to pump 1
    conn.setUnits(units)
    conn.setDiameter(diameter)  
    conn.setVolume(volume)      
    conn.setRate(varrates)  
    conn.setDelay(delay)         
    
    # Specify which pump is having its parameters modified
    conn.changePump(2)
    
    # Setup parameters for pump 2
    units='mL/hr' 			# OPTIONS: 'mL/min','mL/hr','μL/min','μL/hr'
    diameter=28.6           # 28.6mm diameter
    volume=[0.25,5,2]       # Volume = [Step1: 0.25mL, Step2: 5mL, Step3: 2mL]
    delay=[6,12,18]         # Delay  = [Step1: 6s,     Step2: 12s, Step3: 18s]
    
    # Variable flow rates in each step, linear ramping generated by pump
    rate1=[20,5,40]         # between rate1 and rate2 for each step
    rate2=[21,6,41]         # use one rate list for linear flow per step
    varrates=[str(rate1[ii])+'/'+str(rate2[ii]) for ii in range(len(rate1))]
    # Rate = [Step1: 20mL/min->21mL/min, Step2: 5mL/min->6mL/min, Step3: 40mL/min->41mL/min]
    
    # Communicate parameters to pump 2
    conn.setUnits(units)
    conn.setDiameter(diameter)  
    conn.setVolume(volume)      
    conn.setRate(varrates)  
    conn.setDelay(delay)        
    
    # Pump must be started manually on physical GUI
    conn.startPump(multistep=True)
